DEISA documentation
===================

In Situ Data Analytics library built on top of Ray and Dask.

This documentation includes:

- A short guide showing how to write analytics callbacks.
- A full API reference for the :mod:`deisa.ray` package.


.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Guides

   quick_start
   analytics
   tips


.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: API Reference

   deisa.ray
